orion.primitives.azure\_anomaly\_detector.detect\_anomalies
===========================================================

.. currentmodule:: orion.primitives.azure_anomaly_detector

.. autofunction:: detect_anomalies